# Quickstart adon

## Prerequisites

- **adon** understood [No!](https://gitlab.com/elioway/adon/blob/master/doc/abstract.md)
- **elioSin** prerequisites met? [No!](https://gitlab.com/elioway/eliosin/blob/master/doc/installing.md)
- You completed **eve** Quickstart [No!](https://gitlab.com/eliosin/eve/blob/master/doc/quickstart.md)
- You completed **god** Quickstart [No!](https://gitlab.com/eliosin/god/blob/master/doc/quickstart.md)
- You created a new **elioSin** theme called `genesis`.
- You're currently running `gulp` in its root folder and can see the page.

## TLDR Checklist

An adon adds and removes a class to a tagName based on simple user event. The name of the class should be formatted, "adon" + name, e.g. `adonHideWhenClicked`.

1. Create the file `stylesheets/adon/adonHideWhenClicked.scss`

2. Make the tagName the parent tag of the scss, e.g.

```
adonHideWhenClicked {
// get sassy else in here
}
```

1. Reference the style's file in `stylesheets/theme.scss`

2. Add the tagName to the correct _prong_ in `stylesheets/settings.scss`

3. Import the adonName into #{\$container} on `stylesheets/theme.scss`

4. Create the file `js/adon/adonHideWhenClicked.js`

5. Write your logic - basically like this, but cleverer:

```
// NB: Twinned with /stylesheets/adon/adonHideWhenClicked.js
// NB: Tested by /test/adon/adonHideWhenClicked.js
var position = $(window).scrollTop();
jQuery.fn.extend({
adonHideWhenClicked: function() {
return this.toggleClass("adonHideOnScrollDown")
}
});
```

1. Edit `js/main.js`

```
$(document).ready(function() {
$("nav").adonHideOnScrollDown(true);
});
```

1. Edit `js/main.js`

Do steps **1** to **7** in one go:

```

yo sin:adon
```

## An adon which hides tagNames when the page scrolls down

We're going to create an adon which can be used to hide things when the page is scrolling down. You can then add this adon on to any tagNames which you want to hide or show depending on the scrolling behaviour of the user.

Start by calling `yo sin:adon`, which will quickly scaffold all the files needed for your adon, including the beginnings of a test.

```shell
yo sin:adon
```

### What yo sin:adon makes

Respond to the questions, especially choosing an adonName.

This quickstart will assume you chose the name `HideOnScrollDown`.

What yeoman generator produces follows **adon** s _pattern_ which is as follows:

```shell
project
│   ...
│
└───js
│   │   main.js
│   │   ...
│   │
│   └───adon
│       │   adonHideOnScrollDown.js
│       │   ...
│
└───stylesheets
│   │
│   └───adon
│       │   adonHideOnScrollDown.scss
│       │   ...
│
└───test
    │
    └───adon
        │-- adonHideOnScrollDown.js
        │   ...
```

### Editing js/main.js

Manually relate your pluging to some tagNames:

```javascript
// js/main.js
$(document).ready(function() {
  $('aside').adonHideOnScrollDown(true)
  $('blockquote').adonHideOnScrollDown(true)
})
```

This will attach your _adon_ to the tagNames `aside` and `blockquote`.

### Editing js/adon/adonHideOnScrollDown.js

Now we add some functionality into `js/adon/adonHideOnScrollDown.js` where `yo sin:adon` starts you off with this:

```javascript
// js/adon/adonHideOnScrollDown.js
// NB: Twinned with /stylesheets/adon/adonHideOnScrollDown.js
// NB: Tested by /test/adon/adonHideOnScrollDown.js
jQuery.fn.extend({
  adonHideOnScrollDown: function() {
    return this.each(function() {
      var $tag = jQuery(this)
      $tag.addClass('adonHideOnScrollDown')
      return $tag
    })
  },
  _adofHideOnScrollDown: function() {
    return this.each(function() {
      var $tag = jQuery(this)
      $tag.removeClass('adonHideOnScrollDown')
      return $tag
    })
  }
})
```

Change the file to:

```
// NB: Twinned with /stylesheets/adon/adonHideWhenScrollDown.js
// NB: Tested by /test/adon/adonHideWhenScrollDown.js
var position = $(window).scrollTop();
jQuery.fn.extend({
  adonHideWhenScrollDown: function() {
    return this.each(function() {
      var $tag = jQuery(this);
      $(window).scroll(function() {
        var scroll = $(window).scrollTop();
        if (scroll > position) {
          $tag.addClass("adonHideWhenScrollDown");
        } else {
          $tag.removeClass("adonHideWhenScrollDown");
        }
        position = scroll;
      });
      return $tag;
    });
  },
});
```

### Editing stylesheets/adon/adonHideOnScrollDown.scss

Edit the style which your code can activate in `stylesheets/adon/adonHideOnScrollDown.scss`:

```scss
// DEBUG: Twinned with /js/adon/adonHideWhenScrollDown.js
.adonHideWhenScrollDown {
  transition: visibility 0s linear $transition, all 0s;
  transition-timing-function: ease;
  visibility: hidden;
}
```

### Testing your adon stylesheets/adon/adonHideOnScrollDown.scss

Type `yarn test` at the command line. We expect 3 tests to fail.

- [Testing adons](tutorial-testing.md)

## Tidy up

- Press `CTRL` and `C` to stop the browser.

- Type `yarn format` to make your work `prettier`.

- Type `yarn test`. You haven't written any tests yet, but there are 3 tests already which should always pass.

## Next

Now you have seen how to write adons for your elioSin themes.

Go into the world and preach the gospel.

## More

- [god Quickstart](https://gitlab.com/eliosin/eve/blob/master/doc/quickstart.md)
- [eve Quickstart](https://gitlab.com/eliosin/eve/blob/master/doc/quickstart.md)
- [Testing adons](tutorial-testing.md)
- [generator-sin Quickstart](https://gitlab.com/eliosin/generator-sin/blob/master/doc/quickstart.md)
- [Settings File](quickstart.settings-file.md)
- [Mixins](quickstart.mixins.md)
- [god Index](index.md)
